@@ -86,7 +86,7 @@ var gEditorDocumentObserver =
 
         try {
           var spellChecker = new InlineSpellChecker(editor);
-          var prefs = GetPrefs();
+          var prefs = Services.prefs;
           var enabled = prefs.getBoolPref("bluegriffon.spellCheck.enabled");
           spellChecker.enabled = enabled;
           EditorUtils.getCurrentEditorElement().setUserData("spellchecker", spellChecker, null);
@@ -206,8 +206,10 @@ var BlueGriffonPrefsObserver = {
     if (topic != "nsPref:changed")
       return;
 
+    const kSTRUCTUREBAR_PREFS = "bluegriffon.structurebar";
+
     if (prefName == "bluegriffon.returnKey.createsParagraph") {
-      var value = GetPrefs().getBoolPref("bluegriffon.returnKey.createsParagraph");
+      var value = Services.prefs.getBoolPref("bluegriffon.returnKey.createsParagraph");
       var windowEnumerator = Services.wm.getEnumerator("bluegriffon");
       while (windowEnumerator.hasMoreElements()) {
         var w = windowEnumerator.getNext();
@@ -224,7 +226,7 @@ var BlueGriffonPrefsObserver = {
     }
 
     else if (prefName == "bluegriffon.spellCheck.enabled") {
-      var value = GetPrefs().getBoolPref("bluegriffon.spellCheck.enabled");
+      var value = Services.prefs.getBoolPref("bluegriffon.spellCheck.enabled");
       var windowEnumerator = Services.wm.getEnumerator("bluegriffon");
       while (windowEnumerator.hasMoreElements()) {
         var w = windowEnumerator.getNext();
@@ -241,7 +243,7 @@ var BlueGriffonPrefsObserver = {
     }
 
     else if (prefName == "bluegriffon.tabs.position") {
-      var value = GetPrefs().getCharPref("bluegriffon.tabs.position");
+      var value = Services.prefs.getCharPref("bluegriffon.tabs.position");
       var windowEnumerator = Services.wm.getEnumerator("bluegriffon");
       while (windowEnumerator.hasMoreElements()) {
         var w = windowEnumerator.getNext();
@@ -251,7 +253,7 @@ var BlueGriffonPrefsObserver = {
     }
 
     else if (prefName == "bluegriffon.source.theme") {
-      var value = GetPrefs().getCharPref("bluegriffon.source.theme");
+      var value = Services.prefs.getCharPref("bluegriffon.source.theme");
       var windowEnumerator = Services.wm.getEnumerator("bluegriffon");
       while (windowEnumerator.hasMoreElements()) {
         var w = windowEnumerator.getNext();
@@ -264,17 +266,24 @@ var BlueGriffonPrefsObserver = {
       }
     }
     else if (prefName == "bluegriffon.osx.dock-integration") {
-      var value = GetPrefs().getBoolPref("bluegriffon.osx.dock-integration");
+      var value = Services.prefs.getBoolPref("bluegriffon.osx.dock-integration");
       if (value)
         UpdateBadge();
       else
         ResetBadge();
     }
+    else if (prefName.substr(0, kSTRUCTUREBAR_PREFS.length) == kSTRUCTUREBAR_PREFS
+             && gDialog.structurebar.mLastNode)
+      gDialog.structurebar.selectionChanged(
+                null,
+                gDialog.structurebar.mLastNode,
+                gDialog.structurebar.mOneElementSelected);
   }
 };
 
 //@line 53 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
+Components.utils.import("resource://gre/modules/Services.jsm");
 Components.utils.import("resource://app/modules/urlHelper.jsm");
 Components.utils.import("resource://app/modules/editorHelper.jsm");
 Components.utils.import("resource://app/modules/bgQuit.jsm");
@@ -312,6 +321,7 @@ function Startup()
 
   ComposerCommands.setupMainCommands();
   window.updateCommands("style");
+  RestoreShortcuts();
 
   InstallCustomizationDoneCallbacks();
 
@@ -321,9 +331,11 @@ function Startup()
   EditorScrolledNotifier.startup();
   BGZoomManager.startup();
   BGUpdateManager.check();
+  
+  initLocalFontFaceMenu(gDialog.FontFacePopup);
 
   try {
-    var pbi = GetPrefs().QueryInterface(Components.interfaces.nsIPrefBranchInternal);
+    var pbi = Services.prefs.QueryInterface(Components.interfaces.nsIPrefBranchInternal);
     pbi.addObserver("bluegriffon.", BlueGriffonPrefsObserver, false);
   } catch(ex) {
   }
@@ -348,8 +360,8 @@ function LoadLastTabs()
   var lastTabs = "";
   gLastTabsArray = [];
   try {
-    lastTabs = GetPrefs().getCharPref("bluegriffon.defaults.lastTabs");
-    GetPrefs().setCharPref("bluegriffon.defaults.lastTabs", "");
+    lastTabs = Services.prefs.getCharPref("bluegriffon.defaults.lastTabs");
+    Services.prefs.setCharPref("bluegriffon.defaults.lastTabs", "");
   }
   catch(e) {}
   if (lastTabs) {
@@ -372,12 +384,84 @@ function OpenTabFromPreviousSession(aReason, aContext)
   }
 }
 
+function RestoreShortcuts()
+{
+  try {
+    var file = Components.classes["@mozilla.org/file/directory_service;1"]
+                         .getService(Components.interfaces.nsIProperties)
+                         .get("ProfD", Components.interfaces.nsIFile);
+    file.append("shortcuts.sqlite");
+    
+    var storageService = Components.classes["@mozilla.org/storage/service;1"]
+                            .getService(Components.interfaces.mozIStorageService);
+    var dbConn = storageService.openDatabase(file);
+
+    var statement = dbConn.createStatement("SELECT * from shortcuts");
+
+    // remove all existing shortcuts...
+    var elts = document.querySelectorAll("#composer-main-menubar *[key], toolbar *[key]");
+    for (var i = 0; i < elts.length; i++) {
+      var elt = elts[i];
+      var keyId = elt.getAttribute("key");
+      elt.removeAttribute("key");
+      var keyElt = document.getElementById(keyId);
+      if (keyElt) { //sanity check
+        var keyset = keyElt.parentNode;
+        keyset.removeChild(keyElt);
+        var parent = keyset.parentNode;
+        var nextSibling = parent.nextSibling;
+        parent.removeChild(keyset);
+        parent.insertBefore(keyset, nextSibling);
+       }
+    }
+
+    while (statement.executeStep()) {
+      var selector = statement.getUTF8String(1);
+      var modifiers = statement.getUTF8String(2);
+      var key = statement.getUTF8String(3);
+
+      var elt = document.querySelector(selector);
+      // recreate a key
+      var keyset = document.getElementById("mainKeySet");
+      keyElt = document.createElement("key");
+      keyElt.setAttribute("modifiers", modifiers);
+      if (key.length == 1)
+        keyElt.setAttribute("key", key);
+      else
+        keyElt.setAttribute("keycode", key);
+      if (elt.hasAttribute("command"))
+        keyElt.setAttribute("command", elt.getAttribute("command"));
+      if (elt.hasAttribute("oncommand"))
+        keyElt.setAttribute("oncommand", elt.getAttribute("oncommand"));
+      if (!elt.hasAttribute("command") && !elt.hasAttribute("oncommand")) {
+        var cmdStr = 'var e = document.createEvent("Events"); e.initEvent("command", true, true); document.querySelector("'
+                     + selector
+                     +'").dispatchEvent(e);';
+        keyElt.setAttribute("oncommand", cmdStr);
+      }
+
+      var keyId =  "key-" + modifiers.replace( /,/g , "-") + key;
+      keyElt.setAttribute("id", keyId);
+      keyset.appendChild(keyElt);
+      elt.setAttribute("key", keyId);
+
+      var parent = keyset.parentNode;
+      var nextSibling = parent.nextSibling;
+      parent.removeChild(keyset);
+      parent.insertBefore(keyset, nextSibling);
+    }
+    dbConn.close();
+  }
+  catch(e) {
+    // no shortcut DB yet, do nothing
+  }
+}
 //@line 55 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 function Shutdown()
 {
   try {
-    var pbi = GetPrefs().QueryInterface(Components.interfaces.nsIPrefBranchInternal);
+    var pbi = Services.prefs.QueryInterface(Components.interfaces.nsIPrefBranchInternal);
     pbi.removeObserver("bluegriffon.", BlueGriffonPrefsObserver, false);
   } catch(ex) {
   }
@@ -431,7 +515,7 @@ function GetPreferredNewDocumentURL()
 {
   var url = window["kHTML_TRANSITIONAL"];
   try {
-    urlId = GetPrefs().getCharPref("bluegriffon.defaults.doctype");
+    urlId = Services.prefs.getCharPref("bluegriffon.defaults.doctype");
     url = window[urlId]; 
   }
   catch(e) {}
@@ -648,7 +732,7 @@ function onARIARoleChangeStructureBar(commandID)
 
 function initFontFaceMenu(menuPopup)
 {
-  initLocalFontFaceMenu(menuPopup);
+  //initLocalFontFaceMenu(menuPopup);
 
   if (menuPopup)
   {
@@ -733,6 +817,7 @@ function initLocalFontFaceMenu(menuPopup)
       if (BlueGriffonVars.localFonts[i] != "")
       {
         var itemNode = document.createElementNS(BlueGriffonVars.kXUL_NS, "menuitem");
+        itemNode.setAttribute("class", "menuitem-non-iconic-accel");
         itemNode.setAttribute("label", BlueGriffonVars.localFonts[i]);
         itemNode.setAttribute("value", BlueGriffonVars.localFonts[i]);
         if (useRadioMenuitems) {
@@ -1079,7 +1164,7 @@ function ToggleViewMode(aElement)
   if (!aElement) // sanity case
     return;
 
-  var mode =  aElement.getAttribute("value");
+  var mode =  aElement.getAttribute("mode");
   if (mode == GetCurrentViewMode())
     return;
 
@@ -1103,41 +1188,17 @@ function ToggleViewMode(aElement)
     gDialog.structurebar.style.visibility = "hidden";
     HandlersManager.hideAllHandlers();
 
-    const nsIDE = Components.interfaces.nsIDocumentEncoder;
-    var flags = nsIDE.OutputFormatted ;
-    flags |= nsIDE.OutputWrap;
-    flags |= nsIDE.OutputPersistNBSP;
-
-    var osString = Components.classes["@mozilla.org/xre/app-info;1"]
-                     .getService(Components.interfaces.nsIXULRuntime).OS;
-    switch (osString) {
-      case "WINNT":
-        flags |= nsIDE.OutputLFLineBreak;
-        flags |= nsIDE.OutputCRLineBreak;
-        break;
-      case "Darwin":
-        flags |= nsIDE.OutputCRLineBreak;
-        break;
-      case "Linux":
-      default:
-        flags |= nsIDE.OutputLFLineBreak;
-        break;
-    }
-
-    var encodeEntity = GetPrefs().getCharPref("bluegriffon.source.entities");
-    switch (encodeEntity) {
-      case "basic"  : flags |= nsIDE.OutputEncodeBasicEntities;     break;
-      case "latin1" : flags |= nsIDE.OutputEncodeLatin1Entities;    break;
-      case "html"   : flags |= nsIDE.OutputEncodeHTMLEntities;      break;
-      case "unicode": flags |= nsIDE.OutputEncodeCharacterEntities; break;
-      default: break;
-    }
-
     var mimeType = EditorUtils.getCurrentDocument().contentType;
+    const nsIDE = Components.interfaces.nsIDocumentEncoder;
     var encoder = Components.classes["@mozilla.org/layout/documentEncoder;1?type=" + mimeType]
-                   .createInstance(Components.interfaces.nsIDocumentEncoder);
+                   .createInstance(nsIDE);
+
+    var flags = EditorUtils.getSerializationFlags(EditorUtils.getCurrentDocument());
+
     encoder.setCharset("UTF-8");
-    encoder.init(EditorUtils.getCurrentDocument(), mimeType, flags);
+    encoder.init(EditorUtils.getCurrentDocument(), mimeType, flags.value);
+    if (flags.value & nsIDE.OutputWrap)
+      encoder.setWrapColumn(flags.maxColumnPref);
 
     NotifierUtils.notify("beforeEnteringSourceMode");
     var source = encoder.encodeToString();
@@ -1145,6 +1206,10 @@ function ToggleViewMode(aElement)
     var bespinEditor = bespinIframe.contentWindow.gEditor;
     bespinIframe.setUserData("oldSource", source, null);
 
+    var lastEditableChild = editor.document.body.lastChild;
+    if (lastEditableChild.nodeType == Node.TEXT_NODE)
+      lastEditableChild.data = lastEditableChild.data.replace( /\s*$/, "\n");
+
     MarkSelection();
     source = encoder.encodeToString();
 
@@ -1152,6 +1217,14 @@ function ToggleViewMode(aElement)
 
     //bespinEditor.value = "";
     bespinEditor.getSession().setValue(source);
+    bespinEditor.getSession().setUseWrapMode(false);
+    if (flags.value & nsIDE.OutputWrap) {
+      bespinEditor.setShowPrintMargin(true);
+      bespinEditor.setPrintMarginColumn(flags.maxColumnPref);
+    }
+    else {
+      bespinEditor.setShowPrintMargin(false);
+    }
     NotifierUtils.notify("afterEnteringSourceMode");
     editorElement.parentNode.selectedIndex = 0;
 
@@ -1316,7 +1389,7 @@ function doCloseTab(aTab)
   }
   window.updateCommands("style");
   NotifierUtils.notify("tabClosed");
-//@line 967 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 956 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 }
 
 function SetLocationDB()
@@ -1363,8 +1436,17 @@ function doQuit()
 
 function OpenPreferences()
 {
-  var features = "chrome,titlebar,toolbar,centerscreen,dialog=yes";
-  window.openDialog("chrome://bluegriffon/content/prefs/prefs.xul", "Preferences", features);
+  var w = null;
+  try {
+    w = Services.wm.getMostRecentWindow("bluegriffon-prefs");
+  }
+  catch(e){}
+  if (w)
+    w.focus();
+  else {
+    var features = "chrome,titlebar,toolbar,centerscreen,dialog=yes";
+    window.openDialog("chrome://bluegriffon/content/prefs/prefs.xul", "Preferences", features);
+  }
 }
 
 function UpdateSidebarsMenuStatus()
@@ -1954,7 +2036,7 @@ function ReplaceInWysiwyg()
   return true;
 }
 
-//@line 1268 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1266 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 var AutoInsertTable = {
@@ -2089,7 +2171,7 @@ var AutoInsertTable = {
     }
   }
 };
-//@line 1270 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1268 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 function AlignAllPanels()
@@ -2100,9 +2182,9 @@ function AlignAllPanels()
 
 function UpdatePanelsStatusInMenu()
 {
-//@line 1282 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1280 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   return;
-//@line 1285 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1283 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   var child = gDialog.beforeAllPanelsMenuseparator.nextSibling;
   while (child) {
     var panel = gDialog[child.getAttribute("panel")];
@@ -2117,9 +2199,9 @@ function UpdatePanelsStatusInMenu()
 
 function TogglePanel(aEvent)
 {
-//@line 1301 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1299 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   return;
-//@line 1304 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1302 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   var menuitem = aEvent.originalTarget;
   if (!menuitem.hasAttribute("panel"))
     return;
@@ -2283,8 +2365,7 @@ function UpdateSpellCheckMenu(aMenupopup)
 
   var suggestions = 10;
   try {
-    var prefs = GetPrefs();
-    suggestions = prefs.getIntPref("bluegriffon.spellCheck.suggestions");
+    suggestions = Services.prefs.getIntPref("bluegriffon.spellCheck.suggestions");
   }
   catch(e) {}
 
@@ -2321,7 +2402,7 @@ function IgnoreWord()
   sc.ignoreWord();
 }
 
-//@line 1506 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1503 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 function OpenCharInsertionDialog()
 {
   var w = null;
@@ -2335,7 +2416,7 @@ function OpenCharInsertionDialog()
    window.openDialog("chrome://bluegriffon/content/dialogs/insertChars.xul","_blank",
                      "chrome,modal=no,titlebar");
 }
-//@line 1520 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1517 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 var gDummySelectionStartNode = null;
@@ -2506,7 +2587,7 @@ function UseAceTheme(aEvent)
 function SaveCurrentTabLocation()
 {
   try {
-    if (!GetPrefs().getBoolPref("bluegriffon.defaults.restorePreviousSession"))
+    if (!Services.prefs.getBoolPref("bluegriffon.defaults.restorePreviousSession"))
       return;
   }
   catch(e) {}
@@ -2514,12 +2595,12 @@ function SaveCurrentTabLocation()
   var URL = EditorUtils.getDocumentUrl();
   var lastTabs = "";
   try {
-    lastTabs = GetPrefs().getCharPref("bluegriffon.defaults.lastTabs");
+    lastTabs = Services.prefs.getCharPref("bluegriffon.defaults.lastTabs");
   }
   catch(e) {}
   lastTabs += (lastTabs ? "|" : "") + URL;
   try {
-    GetPrefs().setCharPref("bluegriffon.defaults.lastTabs", lastTabs);
+    Services.prefs.setCharPref("bluegriffon.defaults.lastTabs", lastTabs);
   }
   catch(e) {}
 }
@@ -2527,7 +2608,7 @@ function SaveCurrentTabLocation()
 function SaveTabs()
 {
   try {
-    GetPrefs().setCharPref("bluegriffon.defaults.lastTabs", "");
+    Services.prefs.setCharPref("bluegriffon.defaults.lastTabs", "");
   }
   catch(e) {}
 }
