@@ -307,6 +307,8 @@ var ComposerCommands = {
     commandTable.registerCommand("cmd_cleanup",     cmdMarkupCleaner);
     commandTable.registerCommand("cmd_browse",      cmdBrowseCommand);
 
+    commandTable.registerCommand("cmd_list",                 cmdEditListCommand);
+
     commandTable.registerCommand("cmd_table",                cmdInsertOrEditTableCommand);
     commandTable.registerCommand("cmd_editTable",            bgEditTableCommand);
     commandTable.registerCommand("cmd_SelectTable",          bgSelectTableCommand);
@@ -398,6 +400,9 @@ var ComposerCommands = {
     commandTable.registerCommand("cmd_gotoLink",    cmdGotoLinkCommand);
 
     commandTable.registerCommand("cmd_structureClimb", cmdStructureClimbCommand);
+    commandTable.registerCommand("cmd_structureFirstChild", cmdStructureFirstChildCommand);
+    commandTable.registerCommand("cmd_structureNext", cmdStructureNextCommand);
+    commandTable.registerCommand("cmd_structurePrevious", cmdStructurePreviousCommand);
 },
 
   setupFormatCommands: function setupFormatCommands()
@@ -591,10 +596,10 @@ var cmdSave =
     try {
       var docUrl = EditorUtils.getDocumentUrl();
       return EditorUtils.isDocumentEditable()
-			        && (GetCurrentViewMode() == "source"
-					        || (EditorUtils.isDocumentModified()
-					            || UrlUtils.isUrlOfBlankDocument(docUrl)
-					            || UrlUtils.getScheme(docUrl) != "file"));
+              && (GetCurrentViewMode() == "source"
+                  || (EditorUtils.isDocumentModified()
+                      || UrlUtils.isUrlOfBlankDocument(docUrl)
+                      || UrlUtils.getScheme(docUrl) != "file"));
     } catch (e) {return false;}
   },
   
@@ -610,8 +615,8 @@ var cmdSave =
         var mode = GetCurrentViewMode();
         if (mode == "source") {
           var editorElement = EditorUtils.getCurrentEditorElement();
-			    var bespinIframe = editorElement.previousSibling;
-			    var bespinEditor = bespinIframe.contentWindow.gEditor;
+          var bespinIframe = editorElement.previousSibling;
+          var bespinEditor = bespinIframe.contentWindow.gEditor;
           var source = bespinEditor.getSession().getValue();
 
           result = FileUtils.saveSourceDocument(source,
@@ -620,10 +625,10 @@ var cmdSave =
                      EditorUtils.getCurrentDocumentMimeType());
         }
         else {
-	        result = FileUtils.saveDocument(
-	                   UrlUtils.isUrlOfBlankDocument(EditorUtils.getDocumentUrl()),
-	                   false,
-	                   EditorUtils.getCurrentDocumentMimeType());
+          result = FileUtils.saveDocument(
+                     UrlUtils.isUrlOfBlankDocument(EditorUtils.getDocumentUrl()),
+                     false,
+                     EditorUtils.getCurrentDocumentMimeType());
         }
         window.content.focus();
         if (result)
@@ -694,13 +699,13 @@ var cmdCloseTab =
 
   doCommand: function(aCommand)
   {
-	  var editorElement = EditorUtils.getCurrentEditorElement();
+    var editorElement = EditorUtils.getCurrentEditorElement();
     if (!editorElement) // sanity check
       return;
     var mode = editorElement.parentNode.getAttribute("previousMode");
-	  if (mode == "source") {
-	    ToggleViewMode(gDialog.wysiwygModeButton);
-	  }
+    if (mode == "source") {
+      ToggleViewMode(gDialog.wysiwygModeButton);
+    }
     if (EditorUtils.isDocumentModified()) {
       var rv = PromptUtils.confirmWithTitle(
                              L10NUtils.getString("FileNotSaved"),
@@ -950,6 +955,21 @@ var cmdGotoLinkCommand =
   }
 };
 
+function GetSelectionContainerForNavigation()
+{
+  var s = EditorUtils.getCurrentEditor().selection;
+  var r = s.getRangeAt(0);
+  var sc = r.startContainer;
+  if (s.isCollapsed ||
+      (sc == s.getRangeAt(0).endContainer)) {
+    if (sc.nodeType == Node.ELEMENT_NODE)
+      return sc.childNodes.item(r.startOffset);
+    return sc;
+  }
+
+  return s.getRangeAt(0).commonAncestorContainer;
+}
+
 var cmdStructureClimbCommand =
 {
   isCommandEnabled: function(aCommand, dummy)
@@ -966,21 +986,190 @@ var cmdStructureClimbCommand =
 
   doCommand: function(aCommand)
   {
-    var mixed = EditorUtils.getSelectionContainer();
-    if (!mixed) return;
-    var element = mixed.node;
-    var oneElementSelected = mixed.oneElementSelected;
+    var element = GetSelectionContainerForNavigation();
     var editor = EditorUtils.getCurrentEditor();
-    if (oneElementSelected) {
-      if (element.parentNode && element.parentNode != element.ownerDocument.documentElement)
-        editor.selectElement(element.parentNode)
-    }
-    else
-      editor.selectElement(element);
+    if (element.parentNode && element.parentNode != element.ownerDocument.documentElement)
+      editor.selectElement(element.parentNode)
   }
 
 };
 
+var cmdStructureFirstChildCommand =
+{
+  isCommandEnabled: function(aCommand, dummy)
+  {
+    return (EditorUtils.getCurrentEditorElement() &&
+            EditorUtils.isDocumentEditable() &&
+            EditorUtils.isEditingRenderedHTML() &&
+            !EditorUtils.activeViewActive  &&
+            GetCurrentViewMode() == "wysiwyg");
+  },
+
+  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
+  doCommandParams: function(aCommand, aParams, aRefCon) {},
+
+  doCommand: function(aCommand)
+  {
+    var s = EditorUtils.getCurrentEditor().selection;
+    var element = GetSelectionContainerForNavigation();
+    var editor = EditorUtils.getCurrentEditor();
+    if (element && element.firstChild) {
+      if (element.firstChild.nodeType == Node.ELEMENT_NODE)
+        editor.selectElement(element.firstChild);
+      else {
+        var e = element.firstChild;
+        while (e) {
+          if (e.nodeType != Node.TEXT_NODE
+              || e.data.match( /[^\s\r\n]/g )) {
+            if (e.nodeType == Node.ELEMENT_NODE)
+              editor.selectElement(e);
+            else {
+              s.removeAllRanges();
+              var range = EditorUtils.getCurrentDocument().createRange();
+              range.selectNode(e);
+              s.addRange(range);
+            }
+            return;
+          }
+          e = e.nextSibling;
+        }
+      }
+    }
+   }
+
+};
+
+var cmdStructureNextCommand =
+{
+  isCommandEnabled: function(aCommand, dummy)
+  {
+    return (EditorUtils.getCurrentEditorElement() &&
+            EditorUtils.isDocumentEditable() &&
+            EditorUtils.isEditingRenderedHTML() &&
+            !EditorUtils.activeViewActive  &&
+            GetCurrentViewMode() == "wysiwyg");
+  },
+
+  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
+  doCommandParams: function(aCommand, aParams, aRefCon) {},
+
+  doCommand: function(aCommand)
+  {
+    var s = EditorUtils.getCurrentEditor().selection;
+    var element = GetSelectionContainerForNavigation();
+    var editor = EditorUtils.getCurrentEditor();
+    if (element && element.nextSibling) {
+      if (element.nextSibling.nodeType == Node.ELEMENT_NODE)
+        editor.selectElement(element.nextSibling);
+      else {
+        s.removeAllRanges();
+        var range = EditorUtils.getCurrentDocument().createRange();
+        range.selectNode(element.nextSibling);
+        s.addRange(range);
+      }
+    }
+    else {
+      // no next sibling, climb up until we find one
+      var result = null;
+      while (!result
+             && element
+             && element.parentNode != element.ownerDocument.documentElement) {
+        if (element.nextSibling) {
+          var e = element.nextSibling;
+          while (e && !result) {
+            if (e
+                && (e.nodeType != Node.TEXT_NODE
+                    || e.data.match( /[^\s\r\n]/g ))) {
+              result = e;
+            }
+
+            e = e.nextSibling;
+          }
+        }
+
+        element = element.parentNode;
+      }
+
+      if (result) {
+        if (result.nodeType == Node.ELEMENT_NODE)
+          editor.selectElement(result);
+        else {
+          s.removeAllRanges();
+          var range = EditorUtils.getCurrentDocument().createRange();
+          range.selectNode(result);
+          s.addRange(range);
+        }
+      }
+    }
+   }
+
+};
+
+var cmdStructurePreviousCommand =
+{
+  isCommandEnabled: function(aCommand, dummy)
+  {
+    return (EditorUtils.getCurrentEditorElement() &&
+            EditorUtils.isDocumentEditable() &&
+            EditorUtils.isEditingRenderedHTML() &&
+            !EditorUtils.activeViewActive  &&
+            GetCurrentViewMode() == "wysiwyg");
+  },
+
+  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
+  doCommandParams: function(aCommand, aParams, aRefCon) {},
+
+  doCommand: function(aCommand)
+  {
+    var s = EditorUtils.getCurrentEditor().selection;
+    var element = GetSelectionContainerForNavigation();
+    var editor = EditorUtils.getCurrentEditor();
+    if (element && element.previousSibling) {
+      if (element.previousSibling.nodeType == Node.ELEMENT_NODE)
+        editor.selectElement(element.previousSibling);
+      else {
+        s.removeAllRanges();
+        var range = EditorUtils.getCurrentDocument().createRange();
+        range.selectNode(element.previousSibling);
+        s.addRange(range);
+      }
+    }
+    else {
+      // no next sibling, climb up until we find one
+      var result = null;
+      while (!result
+             && element
+             && element.parentNode != element.ownerDocument.documentElement) {
+        if (element.previousSibling) {
+          var e = element.previousSibling;
+          while (e && !result) {
+            if (e
+                && (e.nodeType != Node.TEXT_NODE
+                    || e.data.match( /[^\s\r\n]/g ))) {
+              result = e;
+            }
+
+            e = e.previousSibling;
+          }
+        }
+
+        element = element.parentNode;
+      }
+
+      if (result) {
+        if (result.nodeType == Node.ELEMENT_NODE)
+          editor.selectElement(result);
+        else {
+          s.removeAllRanges();
+          var range = EditorUtils.getCurrentDocument().createRange();
+          range.selectNode(result);
+          s.addRange(range);
+        }
+      }
+    }
+   }
+
+};
 //-----------------------------------------------------------------------------------
 
 var cmdClass =
@@ -1177,6 +1366,28 @@ var cmdPagePropertiesCommand =
   }
 };
 
+var cmdEditListCommand =
+{
+  isCommandEnabled: function(aCommand, dummy)
+  {
+    var element = EditorUtils.getObjectForProperties(["ul","ol"]);
+    return (element &&
+            EditorUtils.getCurrentEditorElement() &&
+            EditorUtils.isDocumentEditable() &&
+            EditorUtils.isEditingRenderedHTML() &&
+            GetCurrentViewMode() == "wysiwyg");
+  },
+
+  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
+  doCommandParams: function(aCommand, aParams, aRefCon) {},
+
+  doCommand: function(aCommand)
+  {
+    window.openDialog("chrome://bluegriffon/content/dialogs/listProperties.xul","_blank",
+                      "chrome,modal,titlebar,resizable=no,dialog=yes");
+   }
+};
+
 var cmdInsertOrEditTableCommand =
 {
   isCommandEnabled: function(aCommand, dummy)
@@ -2552,5 +2763,5 @@ var bgSelectTableColumnCommand =
 };
 
 
-//@line 506 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/commands.js"
+//@line 511 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/commands.js"
 
