@@ -67,7 +67,7 @@ nsUnkownContentTypeDialogProgressListener.prototype = {
   onStateChange: function( aWebProgress, aRequest, aStateFlags, aStatus ) {
   },
 
-  onLocationChange: function( aWebProgress, aRequest, aLocation ) {
+  onLocationChange: function( aWebProgress, aRequest, aLocation, aFlags ) {
   },
 
   onSecurityChange: function( aWebProgress, aRequest, state ) {
@@ -269,13 +269,9 @@ nsUnknownContentTypeDialog.prototype = {
                             .getService(Components.interfaces.nsIDownloadManager);
     picker.displayDirectory = dnldMgr.userDownloadsDirectory;
 
-    var relatedURI = null;
-    if (aContext.document)
-      relatedURI = aContext.document.documentURIObject;
-
     // The last directory preference may not exist, which will throw.
     try {
-      var lastDir = gDownloadLastDir.getFile(relatedURI);
+      var lastDir = gDownloadLastDir.getFile(aLauncher.source);
       if (isUsableDirectory(lastDir))
         picker.displayDirectory = lastDir;
     }
@@ -304,7 +300,7 @@ nsUnknownContentTypeDialog.prototype = {
       var newDir = result.parent.QueryInterface(Components.interfaces.nsILocalFile);
 
       // Do not store the last save directory as a pref inside the private browsing mode
-      gDownloadLastDir.setFile(relatedURI, newDir);
+      gDownloadLastDir.setFile(aLauncher.source, newDir);
 
       result = this.validateLeafName(newDir, result.leafName, null);
     }
@@ -342,7 +338,7 @@ nsUnknownContentTypeDialog.prototype = {
 
     var createdFile = DownloadPaths.createNiceUniqueFile(aLocalFile);
 
-//@line 403 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 399 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
     return createdFile;
   },
@@ -416,7 +412,7 @@ nsUnknownContentTypeDialog.prototype = {
       // want users to be able to autodownload .exe files.
       var rememberChoice = this.dialogElement("rememberChoice");
 
-//@line 497 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 493 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
       if (shouldntRememberChoice) {
         rememberChoice.checked = false;
         rememberChoice.disabled = true;
@@ -565,12 +561,12 @@ nsUnknownContentTypeDialog.prototype = {
   // Returns true if opening the default application makes sense.
   openWithDefaultOK: function() {
     // The checking is different on Windows...
-//@line 656 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 652 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     // On other platforms, default is Ok if there is a default app.
     // Note that nsIMIMEInfo providers need to ensure that this holds true
     // on each platform.
     return this.mLauncher.MIMEInfo.hasDefaultHandler;
-//@line 661 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 657 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
   },
 
   // Set "default" application description field.
@@ -591,9 +587,9 @@ nsUnknownContentTypeDialog.prototype = {
 
   // getPath:
   getPath: function (aFile) {
-//@line 684 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 680 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     return aFile.path;
-//@line 686 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 682 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
   },
 
   // initAppAndSaveToDiskValues:
@@ -823,7 +819,7 @@ nsUnknownContentTypeDialog.prototype = {
         // for the file to be saved to to pass to |saveToDisk| - otherwise
         // we must ask the user to pick a save name.
 
-//@line 929 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 925 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
         // see @notify
         // we cannot use opener's setTimeout, see bug 420405
@@ -878,13 +874,13 @@ nsUnknownContentTypeDialog.prototype = {
   // Retrieve the pretty description from the file
   getFileDisplayName: function getFileDisplayName(file)
   {
-//@line 997 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 993 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     return file.leafName;
   },
 
   // chooseApp:  Open file picker and prompt user for application.
   chooseApp: function() {
-//@line 1045 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 1041 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     var nsIFilePicker = Components.interfaces.nsIFilePicker;
     var fp = Components.classes["@mozilla.org/filepicker;1"]
                        .createInstance(nsIFilePicker);
@@ -901,7 +897,7 @@ nsUnknownContentTypeDialog.prototype = {
                    createInstance(Components.interfaces.nsILocalHandlerApp);
       localHandlerApp.executable = fp.file;
       this.chosenApp = localHandlerApp;
-//@line 1062 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 1058 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
       // Show the "handler" menulist since we have a (user-specified)
       // application now.
