@@ -21,7 +21,7 @@ pref("javascript.options.strict", false);
 pref("nglayout.debug.disable_xul_cache", true);
 pref("nglayout.debug.disable_xul_fastload", true);
 
-pref("general.useragent.extra.mybrowser", "bluegriffon/1.2.1");
+pref("general.useragent.extra.mybrowser", "bluegriffon/1.3.1");
 pref("intl.locale.matchOS", true);
 
 pref("extensions.update.autoUpdateDefault", true);
@@ -88,7 +88,7 @@ pref("signon.SignonFileName", "signons.txt");
 pref("network.protocol-handler.warn-external.http", true);
 pref("network.protocol-handler.warn-external.https", true);
 pref("network.protocol-handler.warn-external.ftp", true);
-pref("network.protocol-handler.expose-all", false);
+pref("network.protocol-handler.expose-all", true);
 
 // XPI
 pref("xpinstall.dialog.confirm", "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul");
@@ -116,6 +116,12 @@ pref("media.autoplay.enabled", false);
 
 pref("bluegriffon.source.theme", "clouds");
 pref("bluegriffon.source.entities", "basic");
+pref("bluegriffon.source.auto-indent", true);
+pref("bluegriffon.source.wrap", true);
+pref("bluegriffon.source.wrap.maxColumn", 80);
+pref("bluegriffon.source.wrap.exclude-languages", true);
+pref("bluegriffon.source.wrap.language-exclusions", "");
+
 pref("bluegriffon.tabs.position", "center");
 
 pref("bluegriffon.osx.dock-integration", true);
