@@ -42,9 +42,9 @@ Components.utils.import("resource://app/modules/prompterHelper.jsm");
 
 var gMain = null;
 var gCurrentElement = null;
-//@line 49 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/sidebars/domexplorer/content/domexplorer.js"
+//@line 49 "/home/glazou/trees/bg1.1/bluegriffon/sidebars/domexplorer/content/domexplorer.js"
 var gIsPanelActive = true;
-//@line 54 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/sidebars/domexplorer/content/domexplorer.js"
+//@line 54 "/home/glazou/trees/bg1.1/bluegriffon/sidebars/domexplorer/content/domexplorer.js"
 var gPrefs = null;
 var gPath = null;
 var gNewAttribute = -1;
@@ -116,7 +116,7 @@ function Shutdown()
                                                 PanelClosed,
                                                 window);
     gDialog.elementsTree.removeEventListener("DOMAttrModified", onElementsTreeModified, true);
-	  gDialog.attributesTree.removeEventListener("DOMAttrModified", onAttributesTreeModified, true);
+    gDialog.attributesTree.removeEventListener("DOMAttrModified", onAttributesTreeModified, true);
     gDialog.cssTree.removeEventListener("DOMAttrModified", onCssTreeModified, true);
   }
 }
@@ -134,9 +134,9 @@ function Inspect()
       }
     }
     else {
-		  var treechildren = gDialog.elementsTree.querySelector("treechildren");
-		  if (treechildren)
-		    gDialog.elementsTree.removeChild(treechildren);
+      var treechildren = gDialog.elementsTree.querySelector("treechildren");
+      if (treechildren)
+        gDialog.elementsTree.removeChild(treechildren);
     }
   }
 }
@@ -186,8 +186,8 @@ function SelectionChanged(aArgs, aElt, aOneElementSelected)
   var treerow  = document.createElement("treerow");
   var treecell = document.createElement("treecell");
   treecell.setAttribute("label", elements[elements.length - 1].nodeName.toLowerCase());
-	treeitem.setUserData("node", elements[elements.length - 1], null);
-	treerow.appendChild(treecell);
+  treeitem.setUserData("node", elements[elements.length - 1], null);
+  treerow.appendChild(treecell);
   treeitem.appendChild(treerow);
   treechildren.appendChild(treeitem);
 
@@ -204,19 +204,19 @@ function SelectionChanged(aArgs, aElt, aOneElementSelected)
       var parent = document.createElement("treechildren");
       treeitem.appendChild(parent);
       while (child) {
-		    treeitem = document.createElement("treeitem");
+        treeitem = document.createElement("treeitem");
         treeitem.setUserData("node", child, null);
-		    treerow  = document.createElement("treerow");
-		    treecell = document.createElement("treecell");
-		    treecell.setAttribute("label", child.nodeName.toLowerCase());
-		    treerow.appendChild(treecell);
-		    treeitem.appendChild(treerow);
-		    parent.appendChild(treeitem);
+        treerow  = document.createElement("treerow");
+        treecell = document.createElement("treecell");
+        treecell.setAttribute("label", child.nodeName.toLowerCase());
+        treerow.appendChild(treecell);
+        treeitem.appendChild(treerow);
+        parent.appendChild(treeitem);
 
         if (i > 0 && child == elements[i-1]) {
           tmp = treeitem;
-	      if (child == gCurrentElement)
-	        selected = treeitem;
+        if (child == gCurrentElement)
+          selected = treeitem;
         }
         child = child.nextElementSibling;
       }
@@ -309,10 +309,10 @@ function onAttributesTreeModified(aEvent)
 
   if (attrName == "editing") {
     if (attrChange == 2) { // start editing
-		  var tree = gDialog.attributesTree;
-		  var contentView = tree.contentView;
-		  var view = tree.view;
-		  gEditing = view.selection.currentIndex;
+      var tree = gDialog.attributesTree;
+      var contentView = tree.contentView;
+      var view = tree.view;
+      gEditing = view.selection.currentIndex;
       gEditingColumn = tree._editingColumn;
     }
     else if (attrChange == 3 && gEditing >= 0) { // end editing
@@ -320,8 +320,8 @@ function onAttributesTreeModified(aEvent)
       var aValue = gDialog.attributesTree.view.getCellText(gEditing, gDialog.attributesTree.columns[1]);
       if (gEditingColumn == gDialog.attributesTree.columns[1]) {
         gMain.EditorUtils.getCurrentEditor().setAttribute(gCurrentElement,
-										                                aName,
-										                                aValue);
+                                                    aName,
+                                                    aValue);
         var notify = (aName.toLowerCase() == "id"
                       || aName.toLowerCase() == "class"
                       || aName.toLowerCase() == "role"
@@ -451,6 +451,7 @@ function DeleteCSS()
   item.parentNode.removeChild(item);
   var txn = new diStyleAttrChangeTxn(gCurrentElement, property, "", "");
   gMain.EditorUtils.getCurrentEditor().transactionManager.doTransaction(txn);
+  gMain.EditorUtils.getCurrentEditor().incrementModificationCount(1);  
   gMain.ComposerCommands.updateSelectionBased(true);
   UpdateAttributes();
 }
@@ -498,8 +499,9 @@ function onCssTreeModified(aEvent)
       var aValue    = gDialog.cssTree.view.getCellText(gEditing, gDialog.cssTree.columns[1]);
       var aPriority = gDialog.cssTree.view.getCellText(gEditing, gDialog.cssTree.columns[2]);
       if (gEditingColumn == gDialog.cssTree.columns[2]) {
-			  var txn = new diStyleAttrChangeTxn(gCurrentElement, aName, aValue, aPriority);
-			  gMain.EditorUtils.getCurrentEditor().transactionManager.doTransaction(txn);
+        var txn = new diStyleAttrChangeTxn(gCurrentElement, aName, aValue, aPriority);
+        gMain.EditorUtils.getCurrentEditor().transactionManager.doTransaction(txn);
+        gMain.EditorUtils.getCurrentEditor().incrementModificationCount(1);  
         gMain.ComposerCommands.updateSelectionBased(true);
         UpdateAttributes();
         gEditing = -1;
