@@ -15,10 +15,10 @@ const ELLIPSIS = Services.prefs.getComplexValue("intl.ellipsis",
 // under the "accessibility.*" branch.
 const PREFS_WHITELIST = [
   "accessibility.",
+  "browser.display.",
   "browser.fixup.",
   "browser.history_expire_",
   "browser.link.open_newwindow",
-  "browser.mousewheel.",
   "browser.places.",
   "browser.startup.homepage",
   "browser.tabs.",
@@ -27,6 +27,7 @@ const PREFS_WHITELIST = [
   "extensions.checkCompatibility",
   "extensions.lastAppVersion",
   "font.",
+  "general.autoScroll",
   "general.useragent.",
   "gfx.",
   "html5.",
@@ -34,7 +35,9 @@ const PREFS_WHITELIST = [
   "javascript.",
   "keyword.",
   "layout.css.dpi",
+  "mousewheel.",
   "network.",
+  "permissions.default.image",
   "places.",
   "plugin.",
   "plugins.",
@@ -141,6 +144,14 @@ function populateGraphicsSection() {
       ]));
     }
   }
+  
+  function pushLiteralInfoRow(table, name, value)
+  {
+    table.push(createParentElement("tr", [
+      createHeader(name),
+      createElement("td", value),
+    ]));
+  }
 
   function errorMessageForFeature(feature) {
     var errorMessage;
@@ -209,7 +220,7 @@ function populateGraphicsSection() {
     pushInfoRow(trGraphics, "driverVersion", gfxInfo.adapterDriverVersion);
     pushInfoRow(trGraphics, "driverDate", gfxInfo.adapterDriverDate);
 
-//@line 285 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 296 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
 
     var webglrenderer;
     var webglenabled;
@@ -220,12 +231,21 @@ function populateGraphicsSection() {
       webglrenderer = false;
       webglenabled = false;
     }
-//@line 303 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 314 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
     var webglfeature = gfxInfo.FEATURE_WEBGL_OPENGL;
-//@line 305 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 316 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
     pushFeatureInfoRow(trGraphics, "webglRenderer", webglfeature, webglenabled, webglrenderer);
 
     appendChildren(graphics_tbody, trGraphics);
+    
+    // display registered graphics properties
+    let graphics_info_properties = document.getElementById("graphics-info-properties");
+    var info = gfxInfo.getInfo();
+    let trGraphicsProperties = [];
+    for (var property in info) {
+      pushLiteralInfoRow(trGraphicsProperties, property, info[property]);
+    }
+    appendChildren(graphics_info_properties, trGraphicsProperties);
    
     // display any failures that have occurred
     let graphics_failures_tbody = document.getElementById("graphics-failures-tbody");
@@ -236,6 +256,8 @@ function populateGraphicsSection() {
     );
     appendChildren(graphics_failures_tbody, trGraphicsFailures);
 
+
+
   } // end if (gfxInfo)
 
   let windows = Services.ww.getWindowEnumerator();
@@ -257,9 +279,9 @@ function populateGraphicsSection() {
   if (acceleratedWindows) {
     msg += " " + mgrType;
   } else {
-//@line 342 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 364 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
     var feature = gfxInfo.FEATURE_OPENGL_LAYERS;
-//@line 344 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 366 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
     var errMsg = errorMessageForFeature(feature);
     if (errMsg)
       msg += ". " + errMsg;
@@ -391,7 +413,7 @@ function createTextForElement(elem) {
   text = text.replace(/\n\n\n+/g, "\n\n");
 
   // Actual CR/LF pairs are needed for some Windows text editors.
-//@line 478 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 500 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
 
   return text;
 }
