@@ -269,21 +269,21 @@ pref("gfx.downloadable_fonts.fallback_delay", 3000);
 pref("gfx.downloadable_fonts.sanitize", true);
 
 // see gfx/thebes/gfxUnicodeProperties.h for definitions of script bits
-//@line 208 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 211 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 // use harfbuzz for default (0x01) + arabic (0x02)
 pref("gfx.font_rendering.harfbuzz.scripts", 3);
-//@line 211 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
-
-//@line 216 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 215 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
 //@line 220 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
+//@line 224 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 227 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 231 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -300,7 +300,7 @@ pref("accessibility.win32.force_disabled", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 247 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 251 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -372,6 +372,7 @@ pref("browser.fixup.alternate.enabled", true);
 pref("browser.fixup.alternate.prefix", "www.");
 pref("browser.fixup.alternate.suffix", ".com");
 pref("browser.fixup.hide_user_pass", true);
+pref("browser.fixup.use-utf8", false);
 
 // Location Bar AutoComplete
 pref("browser.urlbar.autocomplete.enabled", true);
@@ -652,10 +653,14 @@ pref("dom.min_timeout_value", 4);
 // And for background windows
 pref("dom.min_background_timeout_value", 1000);
 
+// Use the new DOM bindings (only affects any scopes created after the pref is
+// changed)
+pref("dom.new_bindings", true);
+
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 600 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 609 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 602 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 611 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -670,15 +675,18 @@ pref("dom.event.contextmenu.enabled",       true);
 
 pref("javascript.enabled",                  true);
 pref("javascript.options.strict",           false);
-//@line 619 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 628 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 pref("javascript.options.relimit",          true);
-pref("javascript.options.tracejit.content",  true);
-pref("javascript.options.tracejit.chrome",   true);
+pref("javascript.options.tracejit.content",  false);
+pref("javascript.options.tracejit.chrome",   false);
 pref("javascript.options.methodjit.content", true);
 pref("javascript.options.methodjit.chrome",  true);
 pref("javascript.options.jitprofiling.content", true);
 pref("javascript.options.jitprofiling.chrome",  true);
+pref("javascript.options.pccounts.content", false);
+pref("javascript.options.pccounts.chrome",  false);
 pref("javascript.options.methodjit_always", false);
+pref("javascript.options.jit_hardening", true);
 pref("javascript.options.typeinference", true);
 // This preference limits the memory usage of javascript.
 // If you want to change these values for your device,
@@ -717,7 +725,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 668 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 680 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -834,7 +842,7 @@ pref("network.http.connection-retry-timeout", 250);
 
 // Disable IPv6 for backup connections to workaround problems about broken
 // IPv6 connectivity.
-pref("network.http.fast-fallback-to-IPv4", false);
+pref("network.http.fast-fallback-to-IPv4", true);
 
 // default values for FTP
 // in a DSCP environment this should be 40 (0x28, or AF11), per RFC-4594,
@@ -871,8 +879,10 @@ pref("network.websocket.timeout.ping.request", 0);
 pref("network.websocket.timeout.ping.response", 10);
 
 // Defines whether or not to try and negotiate the stream-deflate compression
-// extension with the websocket server
-pref("network.websocket.extensions.stream-deflate", true);
+// extension with the websocket server. Stream-Deflate has been removed from
+// the standards track document, but can still be used by servers who opt
+// into it.
+pref("network.websocket.extensions.stream-deflate", false);
 
 // the maximum number of concurrent websocket sessions. By specification there
 // is never more than one handshake oustanding to an individual host at
@@ -1030,10 +1040,6 @@ pref("network.standard-url.escape-utf8", true);
 // UTF-8.
 pref("network.standard-url.encode-utf8", true);
 
-// This preference controls whether or not queries are encoded and sent as
-// UTF-8.
-pref("network.standard-url.encode-query-utf8", false);
-
 // Idle timeout for ftp control connections - 5 minute default
 pref("network.ftp.idleConnectionTimeout", 300);
 
@@ -1069,7 +1075,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 1025 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 1035 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1506,7 +1512,7 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
-//@line 1462 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 1472 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
 pref("dom.ipc.plugins.timeoutSecs", 45);
@@ -1517,18 +1523,18 @@ pref("dom.ipc.plugins.parentTimeoutSecs", 15);
 // How long a plugin launch is allowed to take before
 // we consider it failed.
 pref("dom.ipc.plugins.processLaunchTimeoutSecs", 45);
-//@line 1478 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 1488 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
 // Disable oopp for standard java. They run their own process isolation (which
 // conflicts with our implementation, at least on Windows).
 pref("dom.ipc.plugins.java.enabled", false);
 
-//@line 1486 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 1496 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 // Linux plugins using Xt instead of Xembed don't work out-of-process yet.
 pref("dom.ipc.plugins.enabled.libvlcplugin.so", false);
 pref("dom.ipc.plugins.enabled.nppdf.so", false);
 pref("dom.ipc.plugins.enabled.602plugin.so", false);
-//@line 1493 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 1503 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
 pref("dom.ipc.processCount", 1);
 
@@ -1567,15 +1573,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1997 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 2007 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
-//@line 2430 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 2440 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
-//@line 2630 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 2640 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
-//@line 2899 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 2904 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
-//@line 2903 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 2908 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.protocol-handler.warn-external.file", false);
 pref("browser.drag_out_of_frame_style", 1);
@@ -1608,11 +1614,6 @@ pref("helpers.global_mime_types_file", "/etc/mime.types");
 pref("helpers.global_mailcap_file", "/etc/mailcap");
 pref("helpers.private_mime_types_file", "~/.mime.types");
 pref("helpers.private_mailcap_file", "~/.mailcap");
-pref("java.global_java_version_file", "/etc/.java/versions");
-pref("java.private_java_version_file", "~/.java/versions");
-pref("java.default_java_location_solaris", "/usr/j2se");
-pref("java.default_java_location_others", "/usr/java");
-pref("java.java_plugin_library_name", "javaplugin_oji");
 pref("applications.telnet", "xterm -e telnet %h %p");
 pref("applications.tn3270", "xterm -e tn3270 %h");
 pref("applications.rlogin", "xterm -e rlogin %h");
@@ -1896,7 +1897,7 @@ pref("image.mem.discardable", true);
 
 // Prevents images from automatically being decoded on load, instead allowing
 // them to be decoded on demand when they are drawn.
-pref("image.mem.decodeondraw", false);
+pref("image.mem.decodeondraw", true);
 
 // Minimum timeout for image discarding (in milliseconds). The actual time in
 // which an image must inactive for it to be discarded will vary between this
@@ -1924,20 +1925,24 @@ pref("webgl.force_osmesa", false);
 pref("webgl.osmesalib", "");
 pref("webgl.verbose", false);
 pref("webgl.prefer-native-gl", false);
+pref("webgl.min_capability_mode", false);
+pref("webgl.disable-extensions", false);
+pref("webgl.msaa-level", 2);
+pref("webgl.msaa-force", false);
 
-//@line 3283 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 3287 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
 // Whether to disable acceleration for all widgets.
-//@line 3288 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 3292 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 pref("layers.acceleration.disabled", false);
-//@line 3290 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 3294 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
 // Whether to force acceleration on, ignoring blacklists.
 pref("layers.acceleration.force-enabled", false);
 
 pref("layers.acceleration.draw-fps", false);
 
-//@line 3310 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
+//@line 3314 "/home/glazou/trees/bg1.1/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
@@ -1945,8 +1950,6 @@ pref("geo.enabled", true);
 // Enable/Disable the orientation API for content
 pref("device.motion.enabled", true);
 
-// Enable/Disable HTML5 parser
-pref("html5.parser.enable", true);
 // Toggle which thread the HTML5 parser uses for stream parsing
 pref("html5.offmainthread", true);
 // Time in milliseconds between the time a network buffer is seen and the 
@@ -1966,6 +1969,7 @@ pref("browser.history.maxStateObjectSize", 655360);
 // XPInstall prefs
 pref("xpinstall.whitelist.required", true);
 pref("extensions.alwaysUnpack", false);
+pref("extensions.minCompatiblePlatformVersion", "2.0");
 
 pref("network.buffer.cache.count", 24);
 pref("network.buffer.cache.size",  32768);
@@ -1983,10 +1987,17 @@ pref("alerts.disableSlidingEffect", false);
 pref("full-screen-api.enabled", false);
 pref("full-screen-api.allow-trusted-requests-only", true);
 pref("full-screen-api.key-input-restricted", true);
+pref("full-screen-api.warning.enabled", true);
 
 // Time limit, in milliseconds, for nsEventStateManager::IsHandlingUserInput().
 // Used to detect long running handlers of user-generated events.
 pref("dom.event.handling-user-input-time-limit", 1000);
  
 //3D Transforms
-pref("layout.3d-transforms.enabled", false);
+pref("layout.3d-transforms.enabled", true);
+
+// Battery API
+pref("dom.battery.enabled", true);
+
+// enable JS dump() function.
+pref("browser.dom.window.dump.enabled", false);
