@@ -1,4 +1,6 @@
-//@line 37 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/extensions/content/blocklist.js"
+//@line 37 "/home/glazou/trees/bg1.1/toolkit/mozapps/extensions/content/blocklist.js"
+
+"use strict";
 
 Components.utils.import("resource://gre/modules/Services.jsm");
 
