@@ -1,7 +1,9 @@
-//@line 38 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/extensions/content/update.js"
+//@line 38 "/home/glazou/trees/bg1.1/toolkit/mozapps/extensions/content/update.js"
 
 // This UI is only opened from the Extension Manager when the app is upgraded.
 
+"use strict";
+
 const PREF_UPDATE_EXTENSIONS_ENABLED            = "extensions.update.enabled";
 const PREF_XPINSTALL_ENABLED                    = "xpinstall.enabled";
 
@@ -157,6 +159,10 @@ var gVersionInfoPage = {
   /////////////////////////////////////////////////////////////////////////////
   // UpdateListener
   onUpdateFinished: function(aAddon, status) {
+    // If the add-on is now active then it won't have been disabled by startup
+    if (aAddon.active)
+      AddonManagerPrivate.removeStartupChange("disabled", aAddon.id);
+
     if (status != AddonManager.UPDATE_STATUS_NO_ERROR)
       gUpdateWizard.errorItems.push(aAddon);
 
@@ -395,6 +401,10 @@ var gInstallingPage = {
   },
 
   onInstallEnded: function(aInstall) {
+    // Remember that this add-on was updated during startup
+    AddonManagerPrivate.addStartupChange(AddonManager.STARTUP_CHANGE_CHANGED,
+                                         aInstall.id);
+
     this.startNextInstall();
   },
 
