@@ -1,8 +1,9 @@
-//@line 43 "/home/glazou/trees/OFFICIAL_1.0/toolkit/components/passwordmgr/content/passwordManager.js"
+//@line 43 "/home/glazou/trees/bg1.1/toolkit/components/passwordmgr/content/passwordManager.js"
 
 /*** =================== SAVED SIGNONS CODE =================== ***/
 
 var kSignonBundle;
+var showingPasswords = false;
 
 function SignonsStartup() {
   kSignonBundle = document.getElementById("signonBundle");
@@ -130,7 +131,7 @@ function DeleteAllSignons() {
 }
 
 function TogglePasswordVisible() {
-  if (showingPasswords || ConfirmShowPasswords()) {
+  if (showingPasswords || masterPasswordLogin(AskUserShowPasswords)) {
     showingPasswords = !showingPasswords;
     document.getElementById("togglePasswords").label = kSignonBundle.getString(showingPasswords ? "hidePasswords" : "showPasswords");
     document.getElementById("togglePasswords").accessKey = kSignonBundle.getString(showingPasswords ? "hidePasswordsAccessKey" : "showPasswordsAccessKey");
@@ -156,29 +157,6 @@ function AskUserShowPasswords() {
           null, null, null, null, dummy) == 0;    // 0=="Yes" button
 }
 
-function ConfirmShowPasswords() {
-  // This doesn't harm if passwords are not encrypted
-  var tokendb = Components.classes["@mozilla.org/security/pk11tokendb;1"]
-                    .createInstance(Components.interfaces.nsIPK11TokenDB);
-  var token = tokendb.getInternalKeyToken();
-
-  // If there is no master password, still give the user a chance to opt-out of displaying passwords
-  if (token.checkPassword(""))
-    return AskUserShowPasswords();
-
-  // So there's a master password. But since checkPassword didn't succeed, we're logged out (per nsIPK11Token.idl).
-  try {
-    // Relogin and ask for the master password.
-    token.login(true);  // 'true' means always prompt for token password. User will be prompted until
-                        // clicking 'Cancel' or entering the correct password.
-  } catch (e) {
-    // An exception will be thrown if the user cancels the login prompt dialog.
-    // User is also logged out of Software Security Device.
-  }
-
-  return token.isLoggedIn();
-}
-
 function FinalizeSignonDeletions(syncNeeded) {
   for (var s=0; s<deletedSignons.length; s++) {
     passwordmanager.removeLogin(deletedSignons[s]);
@@ -331,6 +309,10 @@ function _filterPasswords()
 }
 
 function CopyPassword() {
+  // Don't copy passwords if we aren't already showing the passwords & a master
+  // password hasn't been entered.
+  if (!showingPasswords && !masterPasswordLogin())
+    return;
   // Copy selected signon's password to clipboard
   var clipboard = Components.classes["@mozilla.org/widget/clipboardhelper;1"].
                   getService(Components.interfaces.nsIClipboardHelper);
@@ -347,3 +329,26 @@ function UpdateCopyPassword() {
   else
     menuitem.setAttribute("disabled", "true");
 }
+
+function masterPasswordLogin(noPasswordCallback) {
+  // This doesn't harm if passwords are not encrypted
+  var tokendb = Components.classes["@mozilla.org/security/pk11tokendb;1"]
+                    .createInstance(Components.interfaces.nsIPK11TokenDB);
+  var token = tokendb.getInternalKeyToken();
+
+  // If there is no master password, still give the user a chance to opt-out of displaying passwords
+  if (token.checkPassword(""))
+    return noPasswordCallback ? noPasswordCallback() : true;
+
+  // So there's a master password. But since checkPassword didn't succeed, we're logged out (per nsIPK11Token.idl).
+  try {
+    // Relogin and ask for the master password.
+    token.login(true);  // 'true' means always prompt for token password. User will be prompted until
+                        // clicking 'Cancel' or entering the correct password.
+  } catch (e) {
+    // An exception will be thrown if the user cancels the login prompt dialog.
+    // User is also logged out of Software Security Device.
+  }
+
+  return token.isLoggedIn();
+}
